@@ -56,9 +56,10 @@ class _VariableExtender:
 
     def extend(self, string, relative=False):
         """
-        @param string: string to replace
+        Expand a variable.
+        @param string: string to replace.
         @param relative: if True, assume the content of all variables
-          to be relative to the prefix
+            to be relative to the prefix.
         """
         for name, var in [('sysconfdir', self.sysconfdir),
                           ('datadir', self.datadir),
@@ -73,6 +74,11 @@ class KiwiInstallLib(install_lib):
     resources = {}
     global_resources = {}
 
+    def _get_template(self):
+        return os.path.join(self.install_dir,
+                            self.distribution.get_name(),
+                            '__installed__.py')
+
     def generate_template(self):
         if 'bdist_wininst' in sys.argv:
             prefix = 'import sys\nprefix = sys.prefix'
@@ -81,8 +87,7 @@ class KiwiInstallLib(install_lib):
             # Use raw strings so UNC paths which has \\ works
             prefix = 'prefix = r"%s"' % install.prefix or sys.prefix
 
-        name = self.distribution.get_name()
-        filename = os.path.join(self.install_dir, name, '__installed__.py')
+        filename = self._get_template()
         self.mkpath(os.path.dirname(filename))
         fp = open(filename, 'w')
         fp.write('# Generated by setup.py do not modify\n')
@@ -112,6 +117,12 @@ class KiwiInstallLib(install_lib):
             fp.write("%s['%s'] = %s\n" % (
                 name, key, 'os.path.join(%s)' % ', '.join(parts)))
 
+    def get_outputs(self):
+        filename = self._get_template()
+        files = [filename] + self._bytecode_filenames([filename])
+
+        return install_lib.get_outputs(self) + files
+
     def install(self):
         self.varext = _VariableExtender(self.distribution)
         return install_lib.install(self) + [self.generate_template()]
@@ -212,8 +223,11 @@ def listpackages(root, exclude=None):
     """
 
     packages = []
+    if not os.path.exists(root):
+        raise ValueError("%s does not exists" % (root,))
+
     if not os.path.isdir(root):
-        raise ValueError("root must be a directory")
+        raise ValueError("%s must be a directory" % (root,))
 
     if os.path.exists(os.path.join(root, '__init__.py')):
         packages.append(root.replace('/', '.'))
@@ -234,9 +248,9 @@ def setup(**kwargs):
     """
     A drop in replacement for distutils.core.setup which
     integrates nicely with kiwi.environ
-    @kwarg resources:
-    @kwarg global_resources:
-    @kwarg templates: List of templates to install
+    @var resources:
+    @var global_resources:
+    @var templates: List of templates to install
     """
     resources = {}
     global_resources = {}
@@ -249,7 +263,9 @@ def setup(**kwargs):
         templates = kwargs.pop('templates')
 
     def run_install(self):
-        self.data_files.extend(compile_po_files(kwargs['name']))
+        name = kwargs.get('name')
+        if name:
+           self.data_files.extend(compile_po_files(name))
         KiwiInstallData.run(self)
 
         varext = _VariableExtender(self.distribution)
